def Lsegitiga(alas:float, tinggi:float) -> float :
    luas = (alas*tinggi)/2
    return luas

def Lpersegi(panjang:float, lebar:float) -> float :
    luas = panjang * lebar
    return luas



def Vlimas(panjang:float, lebar:float, tinggi:float) -> float :
    volume = (panjang * lebar * tinggi)/3
    return volume

def Vbalok(panjang:float, lebar:float, tinggi:float) -> float:
    volume = panjang*lebar*tinggi
    return volume